# CHANGELOG

<!-- version list -->

## v1.2.0 (2026-01-15)

### Code Style

- Fix ruff linting errors
  ([`b2d5ea2`](https://github.com/pirnerjonas/argus/commit/b2d5ea2c4d0715a474d4ffaa5be60d0499d200a2))

- Remove unused pytest import in test_classification.py
  ([`e22175a`](https://github.com/pirnerjonas/argus/commit/e22175a7378276dd2840754e672c7d4d1ed0e067))

### Features

- Add classification dataset support with grid viewer
  ([`8089bd3`](https://github.com/pirnerjonas/argus/commit/8089bd3367ede4c288b0276ac3da4d3ef9960c4d))


## v1.1.0 (2026-01-14)

### Code Style

- Fix line too long in _get_display_image
  ([`7a56904`](https://github.com/pirnerjonas/argus/commit/7a569049baa4e90956e089d970e192eb159a57e0))

### Features

- Add toggle for annotation overlay in view command
  ([`65fb239`](https://github.com/pirnerjonas/argus/commit/65fb23942d53947df57b6e4c12d11e5dd1aa98f3))


## v1.0.1 (2026-01-12)

### Bug Fixes

- Rename CLI command from argus to argus-cv
  ([`325ef2a`](https://github.com/pirnerjonas/argus/commit/325ef2acfad88d179ab5b4c5e2d2621e34f9fa7e))


## v1.0.0 (2026-01-12)


## v0.1.0 (2026-01-12)

- Initial Release
